﻿using ELTE.TodoList.Web.Models;
using Microsoft.EntityFrameworkCore;

namespace ELTE.TodoList.Web.Services
{
    public class TodoListService: ITodoListService
    {
        private readonly TodoListDbContext _context;

        public TodoListService(TodoListDbContext context)
        {
            _context = context;
        }

        public List<List> GetLists(String? name = null)
        {
            return _context.Lists
                .Where(l => l.Name.Contains(name ?? ""))
                .OrderBy(l => l.Name)
                .ToList();
        }

        public List GetListByID(int id)
        {
            return _context.Lists
                .Single(l => l.Id == id); // throws InvalidOperationException if id not found
        }

        public List<Item> GetItemsByListID(int id)
        {
            return _context.Items
                 .Where(i => i.ListId == id)
                 .ToList();
        }

        public List GetListDetails(int id)
        {
            return _context.Lists
                .Include(l => l.Items)
                .Single(l => l.Id == id);
        }

        public Item? GetItem(int id)
        {
            return _context.Items
                 .FirstOrDefault(i => i.Id == id);
        }
    }
}
